==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/sch/model/MonitoringSourceDetails.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.sch.model;

/**
 * The Monitoring source. For configuration instructions, see [Creating a Connector with a
 * Monitoring
 * Source](https://docs.cloud.oracle.com/iaas/Content/connector-hub/create-service-connector-monitoring-source.htm).
 * <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200909")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = MonitoringSourceDetails.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "kind")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class MonitoringSourceDetails extends SourceDetails {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /** One or more compartment-specific lists of metric namespaces to retrieve data from. */
        @com.fasterxml.jackson.annotation.JsonProperty("monitoringSources")
        private java.util.List<MonitoringSource> monitoringSources;

        /**
         * One or more compartment-specific lists of metric namespaces to retrieve data from.
         *
         * @param monitoringSources the value to set
         * @return this builder
         */
        public Builder monitoringSources(java.util.List<MonitoringSource> monitoringSources) {
            this.monitoringSources = monitoringSources;
            this.__explicitlySet__.add("monitoringSources");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public MonitoringSourceDetails build() {
            MonitoringSourceDetails model = new MonitoringSourceDetails(this.monitoringSources);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(MonitoringSourceDetails model) {
            if (model.wasPropertyExplicitlySet("monitoringSources")) {
                this.monitoringSources(model.getMonitoringSources());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public MonitoringSourceDetails(java.util.List<MonitoringSource> monitoringSources) {
        super();
        this.monitoringSources = monitoringSources;
    }

    /** One or more compartment-specific lists of metric namespaces to retrieve data from. */
    @com.fasterxml.jackson.annotation.JsonProperty("monitoringSources")
    private final java.util.List<MonitoringSource> monitoringSources;

    /**
     * One or more compartment-specific lists of metric namespaces to retrieve data from.
     *
     * @return the value
     */
    public java.util.List<MonitoringSource> getMonitoringSources() {
        return monitoringSources;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("MonitoringSourceDetails(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", monitoringSources=").append(String.valueOf(this.monitoringSources));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof MonitoringSourceDetails)) {
            return false;
        }

        MonitoringSourceDetails other = (MonitoringSourceDetails) o;
        return java.util.Objects.equals(this.monitoringSources, other.monitoringSources)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.monitoringSources == null ? 43 : this.monitoringSources.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/sch/model/MonitoringSourceDetails.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.sch.model;

/**
 * The Monitoring source. For configuration instructions, see [Creating a Connector with a
 * Monitoring
 * Source](https://docs.oracle.com/iaas/Content/connector-hub/create-service-connector-monitoring-source.htm).
 * <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200909")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = MonitoringSourceDetails.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "kind")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class MonitoringSourceDetails extends SourceDetails {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /** One or more compartment-specific lists of metric namespaces to retrieve data from. */
        @com.fasterxml.jackson.annotation.JsonProperty("monitoringSources")
        private java.util.List<MonitoringSource> monitoringSources;

        /**
         * One or more compartment-specific lists of metric namespaces to retrieve data from.
         *
         * @param monitoringSources the value to set
         * @return this builder
         */
        public Builder monitoringSources(java.util.List<MonitoringSource> monitoringSources) {
            this.monitoringSources = monitoringSources;
            this.__explicitlySet__.add("monitoringSources");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public MonitoringSourceDetails build() {
            MonitoringSourceDetails model = new MonitoringSourceDetails(this.monitoringSources);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(MonitoringSourceDetails model) {
            if (model.wasPropertyExplicitlySet("monitoringSources")) {
                this.monitoringSources(model.getMonitoringSources());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public MonitoringSourceDetails(java.util.List<MonitoringSource> monitoringSources) {
        super();
        this.monitoringSources = monitoringSources;
    }

    /** One or more compartment-specific lists of metric namespaces to retrieve data from. */
    @com.fasterxml.jackson.annotation.JsonProperty("monitoringSources")
    private final java.util.List<MonitoringSource> monitoringSources;

    /**
     * One or more compartment-specific lists of metric namespaces to retrieve data from.
     *
     * @return the value
     */
    public java.util.List<MonitoringSource> getMonitoringSources() {
        return monitoringSources;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("MonitoringSourceDetails(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", monitoringSources=").append(String.valueOf(this.monitoringSources));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof MonitoringSourceDetails)) {
            return false;
        }

        MonitoringSourceDetails other = (MonitoringSourceDetails) o;
        return java.util.Objects.equals(this.monitoringSources, other.monitoringSources)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.monitoringSources == null ? 43 : this.monitoringSources.hashCode());
        return result;
    }
}
